@@ -49,7 +49,7 @@ def preprocess(sentence, remove_punct, remove_stop_words, stemm, lang='en'):
         
         
 class sentence_tranformer():
-    def __init__(self, source_names, target_names, model=None, return_match_idx=False):
+    def __init__(self, source_names, target_names, model=None, return_match_idx=False, lang='en'):
         if not source_names:
             raise Exception('Inputs are empty')
         
@@ -69,7 +69,12 @@ class sentence_tranformer():
         # if no model is provided use the default model
         if model is None:
             print('initializing the model...')
-            self.model = SentenceTransformer('paraphrase-MiniLM-L6-v2')
+            if lang.lower() == 'en':
+                self.model = SentenceTransformer('all-MiniLM-L6-v2')
+            else:
+                self.model = SentenceTransformer('paraphrase-multilingual-mpnet-base-v2')
+            # else:
+            #     raise Exception('unknown language entered')
 
         # encode the targets
         self.encoded_targets = self.model.encode(self.target_names)
